@@ -79,7 +79,7 @@ TCustomButton*              Donate_Current;
 
 //---------------------------------------------------------------------------
 extern const ZenLib::Char* MEDIAINFO_TITLE;
-const size_t Title_Pos=96; //TODO: Position of Title in General.csv, should shange this...
+const size_t Title_Pos=156; //TODO: Position of Title in General.csv, should shange this...
 MediaInfoList *I;
 //---------------------------------------------------------------------------
 
@@ -213,6 +213,8 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("Text")) {M_View_TextClick(NULL); M_View_Text->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("HTML")) {M_View_HTMLClick(NULL); M_View_HTML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("MIXML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("JSON")) {M_View_JSONClick(NULL); M_View_JSON->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
@@ -225,6 +227,7 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.1")) {M_View_FIMS_1_1Click(NULL); M_View_FIMS_1_1->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.2")) {M_View_FIMS_1_2Click(NULL); M_View_FIMS_1_2->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.3")) {M_View_FIMS_1_3Click(NULL); M_View_FIMS_1_3->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("NISO_Z39.87")) {M_View_NISO_Z39_87Click(NULL); M_View_NISO_Z39_87->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("reVTMD")) {M_View_reVTMDClick(NULL); M_View_reVTMD->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("Custom")) {M_View_CustomClick(NULL); M_View_Custom->Checked=true;}
 
@@ -693,6 +696,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         Page_Tree_Tree->Items->Clear();
         TTreeNode* Top=NULL;
 
+        I->Option(__T("File_ExpandSubs"), __T("1"));
         for (size_t FilePos=0; FilePos<FilesCount; FilePos++)
         {
             //Pour chaque fichier
@@ -716,6 +720,10 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                         A+=B;
                     }
                     TTreeNode* Node=Page_Tree_Tree->Items->AddChild(Parent, A.c_str());
+
+                    std::vector<TTreeNode*> Tree;
+                    Tree.push_back(Node);
+
                     unsigned ChampsCount=I->Count_Get(FilePos, (stream_t)StreamKind, StreamPos);
                     for (size_t Champ_Pos=0; Champ_Pos<ChampsCount; Champ_Pos++)
                     {
@@ -731,13 +739,29 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                             if (D.empty())
                                 D=I->Get(FilePos, (stream_t)StreamKind, StreamPos, Champ_Pos, Info_Name); //Texte n'existe pas
                             //Affichage
-                            Page_Tree_Tree->Items->AddChild(Node, (D + __T(": ") + A.c_str()).c_str());
+                            size_t Level=D.find_first_not_of(__T(' '));
+
+                            bool Hide=false;
+                            if (A==__T("Yes") && Champ_Pos+1<ChampsCount)
+                                Hide=I->Get(FilePos, (stream_t)StreamKind, StreamPos, Champ_Pos+1, Info_Name_Text).find_first_not_of(__T(' '))>Level;
+
+                            if (Level && Level!=(size_t)-1)
+                                D=D.substr(Level);
+
+                            if(Level==Tree.size() && Tree.back()->GetLastChild())
+                                Tree.push_back(Tree.back()->GetLastChild());
+                            else if(Level<Tree.size()-1)
+                                Tree.resize(Level+1);
+
+                            Page_Tree_Tree->Items->AddChild(Tree.back(), Hide?D.c_str():(D + __T(": ") + A).c_str());
                         }
                     }
+                    Node->Expand(false);
                 }
             }
+            Parent->Expand(false);
         }
-        Page_Tree_Tree->FullExpand();
+        I->Option(__T("File_ExpandSubs"), __T("0"));
         if (Top)
             Top->MakeVisible();
         Page_Tree_Tree->Visible=true;
@@ -801,7 +825,9 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     else if (Page==Page_Custom)
     {
         if (M_View_XML->Checked)
-            I->Option_Static(__T("Inform"), __T("XML"));
+            I->Option_Static(__T("Inform"), __T("MIXML"));
+        else if (M_View_JSON->Checked)
+            I->Option_Static(__T("Inform"), __T("JSON"));
         else if (M_View_MPEG7->Checked)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
@@ -828,6 +854,8 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("FIMS_1.3"));
         else if (M_View_reVTMD->Checked)
             I->Option_Static(__T("Inform"), __T("reVTMD"));
+        else if (M_View_NISO_Z39_87->Checked)
+            I->Option_Static(__T("Inform"), __T("NISO_Z39.87"));
         else
             I->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
         Ztring S1=I->Inform();
@@ -1106,14 +1134,26 @@ void __fastcall TMainF::M_View_XMLClick(TObject *Sender)
     //Language
     I->Option_Static(__T("Language"), __T("raw"));
 
-    Prefs->Details[Prefs_Custom].Write(__T("XML"));
+    M_View_XML->Checked=true;
     ToolBar_View_XML->Checked=true;
     ChangePage(Page_Custom);
 }
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_JSONClick(TObject *Sender)
+{
+    //Language
+    I->Option_Static(__T("Language"), __T("raw"));
+
+    M_View_JSON->Checked=true;
+    ToolBar_View_JSON->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("MPEG-7"));
+    M_View_MPEG7->Checked=true;
     ToolBar_View_MPEG7->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1121,15 +1161,23 @@ void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_reVTMDClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("reVTMD"));
+    M_View_reVTMD->Checked=true;
     ToolBar_View_reVTMD->Checked=true;
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_NISO_Z39_87Click(TObject *Sender)
+{
+    M_View_NISO_Z39_87->Checked=true;
+    ToolBar_View_NISO_Z39_87->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("PBCore_1.2"));
+    M_View_PBCore->Checked=true;
     ToolBar_View_PBCore->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1137,7 +1185,7 @@ void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCore2Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("PBCore_2.0"));
+    M_View_PBCore2->Checked=true;
     ToolBar_View_PBCore2->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1145,7 +1193,7 @@ void __fastcall TMainF::M_View_PBCore2Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.5"));
+    M_View_EBUCore_1_5->Checked=true;
     ToolBar_View_EBUCore_1_5->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1153,7 +1201,7 @@ void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.6"));
+    M_View_EBUCore_1_6->Checked=true;
     ToolBar_View_EBUCore_1_6->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1161,7 +1209,7 @@ void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_psClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps"));
+    M_View_EBUCore_1_8_ps->Checked=true;
     ToolBar_View_EBUCore_1_8_ps->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1169,7 +1217,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_psClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_spClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp"));
+    M_View_EBUCore_1_8_sp->Checked=true;
     ToolBar_View_EBUCore_1_8_sp->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1177,7 +1225,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_spClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_ps_jsonClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps_json"));
+    M_View_EBUCore_1_8_ps_json->Checked=true;
     ToolBar_View_EBUCore_1_8_ps_json->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1185,7 +1233,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_ps_jsonClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_sp_jsonClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp_json"));
+    M_View_EBUCore_1_8_sp_json->Checked=true;
     ToolBar_View_EBUCore_1_8_sp_json->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1193,7 +1241,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_sp_jsonClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.1"));
+    M_View_FIMS_1_1->Checked=true;
     ToolBar_View_FIMS_1_1->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1201,7 +1249,7 @@ void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_2Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.2"));
+    M_View_FIMS_1_2->Checked=true;
     ToolBar_View_FIMS_1_2->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1209,7 +1257,7 @@ void __fastcall TMainF::M_View_FIMS_1_2Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_3Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.3"));
+    M_View_FIMS_1_3->Checked=true;
     ToolBar_View_FIMS_1_3->Checked=true;
     ChangePage(Page_Custom);
 }
